Class: ConcernsOnRails::Railtie

Inherits:
Rails::Railtie
  • Object
show all
Defined in:
lib/concerns_on_rails/railtie.rb

Overview

Boot-time integration, loaded only when Rails is present (see the conditional require at the bottom of lib/concerns_on_rails.rb).